import requests

class WeatherFetcher:
    def __init__(self, api_url="https://api.theanon.xyz/weather"):
        self.api_url = api_url

    def get_weather(self, city):
        response = requests.get(self.api_url, params={"city": city})
        data = response.json()

        if response.status_code != 200:
            raise Exception(data.get("error", "Failed to fetch weather"))

        return data



from setuptools import setup, find_packages

setup(
    name="anonweather",
    version="0.1.0",
    description="Weather module using api.theanon.xyz API",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    author="Amit Ranabhat",
    author_email="ranabhatamit04@gmail,com",
    url="https://api.theanon.xyz",
    packages=find_packages(),
    install_requires=["requests"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License"
    ],
    python_requires='>=3.6',
)
